==> nektar-4.3.0.tar.xz: nektar++-4.3.0/utilities/NekMesh/ProcessModules/ProcessExtractTetPrismInterface.h <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: ProcessExtractTetPrismInterface.h
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  License for the specific language governing rights and limitations under
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: Extract the interface between prismatic and tetrahedral
//  elements.
//
////////////////////////////////////////////////////////////////////////////////

#ifndef UTILITIES_NEKMESH_PROCESSEXTRACTTETPRISMINTERFACE
#define UTILITIES_NEKMESH_PROCESSEXTRACTTETPRISMINTERFACE

#include "../Module.h"

namespace Nektar
{
namespace Utilities
{

/**
 * @brief Module to extract interface between prismatic and tetrahedral
 * elements.
 */
class ProcessExtractTetPrismInterface : public ProcessModule
{
public:
    /// Creates an instance of this class
    static boost::shared_ptr<Module> create(MeshSharedPtr m)
    {
        return MemoryManager<
            ProcessExtractTetPrismInterface>::AllocateSharedPtr(m);
    }
    static ModuleKey className;

    ProcessExtractTetPrismInterface(MeshSharedPtr m);
    virtual ~ProcessExtractTetPrismInterface();

    /// Write mesh to output file.
    virtual void Process();
};
}
}

#endif

==> nektar-4.4.1.tar.xz: nektar++-4.4.1/utilities/NekMesh/ProcessModules/ProcessExtractTetPrismInterface.h <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: ProcessExtractTetPrismInterface.h
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2006 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  License for the specific language governing rights and limitations under
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: Extract the interface between prismatic and tetrahedral
//  elements.
//
////////////////////////////////////////////////////////////////////////////////

#ifndef UTILITIES_NEKMESH_PROCESSEXTRACTTETPRISMINTERFACE
#define UTILITIES_NEKMESH_PROCESSEXTRACTTETPRISMINTERFACE

#include <NekMeshUtils/Module/Module.h>

namespace Nektar
{
namespace Utilities
{

/**
 * @brief Module to extract interface between prismatic and tetrahedral
 * elements.
 */
class ProcessExtractTetPrismInterface : public NekMeshUtils::ProcessModule
{
public:
    /// Creates an instance of this class
    static boost::shared_ptr<Module> create(NekMeshUtils::MeshSharedPtr m)
    {
        return MemoryManager<
            ProcessExtractTetPrismInterface>::AllocateSharedPtr(m);
    }
    static NekMeshUtils::ModuleKey className;

    ProcessExtractTetPrismInterface(NekMeshUtils::MeshSharedPtr m);
    virtual ~ProcessExtractTetPrismInterface();

    /// Write mesh to output file.
    virtual void Process();
};
}
}

#endif
